from WaterProbe import WaterProbe

class Hydration(list):
    """Class Hydration

    The class Hydration is a container for WaterProbes, just like MacroMolecule
    and Ligand are containers for MacroMoleculeAtoms and LigandAtoms.

    Examples:
    >>> from Hydration import Hydration
    >>> H = Hydration()
    >>> import Radii
    >>> R = Radii.Radii()
    >>> R.radii_set = 'LI_AND_NUSSINOV'
    >>> H.atom_input(1, 101, 101, ' O  ', 'O', 18.615, 2.504, 29.763, 3, 0)
    >>> H.atom_input(1, 102, 102, ' O  ', 'O', 16.615, 2.504, 29.763, 3, 0)
    >>> len(H)
    2
    >>> for water in H:
    ...     print water.atom_org_id
    101
    102

    """
    
    def atom_input(self, hydration_layer, resOrgId, atom_org_id,
                   atom_org_name, atom_type, x, y, z, sub_atom_type,
                   molecule_instance, experimental=False):
        """function atom_input
        
        hydration_layer: int
        resOrgId: int
        atom_org_id: int
        atom_org_name: string
        atom_type: string
        x: float
        y: float
        z: float
        sub_atom_type: int
        molecule_instance: int
        
        This method is used to input a new WaterProbe into the list.
        
        See the Atom and WaterProbe class for explanations of the arguments
        passed into this method.

        """
        self.append(WaterProbe(atom_org_id,
                               atom_org_name,
                               atom_type,
                               x, y, z,
                               sub_atom_type,
                               molecule_instance,
                               resOrgId,
                               experimental))
        self[-1].hydration_layer = hydration_layer
        self[-1].include = 1

    def clear(self):
        """
        Clear list.

        Including neighbor lists and surface points.

        """
        exp = []
        for atom in self:
            atom.clear_neighbors()
            atom.clear_surface()
            if atom.experimental == 1:
                exp.append(atom)
        del self[:]
        self.extend(exp)
        
# Test Hydration class by 'python Hydration.py'
if __name__ == "__main__":
    import doctest
    doctest.testmod()
