from Point import Point
from math import cos, sin

class UnitSurfacePoints(object):
    """Class UnitSurfacePoints

    The class UnitSurfacePoints is a container of instances of the class
    Point.  The Point instnaces are held in the attribute _point_list. All the
    points in _point_list are unit (1 A) away from the origin (0.0, 0.0, 0.0),
    for example (1.0, 0.0, 0.0), (0.0, 1.0, 0.0) and (0.0, 0.0, 1.0).

    The attribute _point_list is filled automatically upon the generation of an
    instance of the class UnitSurfacePoints.

    Attributes:
    point_list    -- list of points unit distance from origin.

    Methods:
    __init__      -- Initialize an instance.

    Examples:
    >>> from UnitSurfacePoints import UnitSurfacePoints
    >>> u = UnitSurfacePoints()
    >>> len(u.point_list)
    126

    """
    
    # Operations
    def __init__(self):
        """function __init__
        
        Generate points uniformly on a unit sphere.


        returns None
        """
        self._point_list = []
        if len(self._point_list) > 0: # the list has already been generated
            return False
        nstep = 10
        PI = 3.1415926536
        theta = PI/nstep
        arc = theta
        self._point_list.append( Point(0.0, 1.0, 0.0) )
        self._point_list.append( Point(0.0, -1.0, 0.0) )
        for istep in range(nstep):
            istep = istep + 1    # to change range from 0--9 to 1--10
            y1 = cos(istep*theta)
            r2 = sin(istep*theta)
            ndot2= 2*PI*r2/arc
            if ndot2 == 0.0:
                continue
            theta2 = 2*PI/ndot2
            for idot in range(int(ndot2)):
                idot = idot + 1  # to change range from 0-- to 1--
                x2 = r2*cos(idot*theta2)
                z2 = r2*sin(idot*theta2)
                self._point_list.append( Point(x2, y1, z2) )

        return None
    
    @property
    def point_list(self):
        """This is an accessor for point_list attribute -- read-only."""
        return self._point_list

# Test UnitSurfacePoints by running the command 'python UnitSurfacePoints.py'
if __name__ == "__main__":
    A = UnitSurfacePoints()
    B = Point(0.0, 0.0, 0.0)
    for i, point in enumerate( A.point_list ):
        print i, "d2:", B.get_distance2(point),
        print point
    print "Kinamage file below:"
    print "@kinemage"
    print "@dotlist{Unit surface points}"
    for i, point in enumerate( A.point_list ):
        print "{", i, "}",
        print "%.2f %.2f %.2f" % (point.x, point.y, point.z)
    import doctest
    doctest.testmod()
