def attributes_from_dict(d):
    """
    Function for automatically initializing instance variables from __init__
    arguments.

    See:
    Python Cookbook, 2nd ed, page 280-282.

    """
    self = d.pop('self')
    for n, v in d.iteritems():
        setattr(self, n, v)

class Singleton(object):
    """
    A Pythonic Singleton

    See:
    Python Cookbook, 2nd ed, page 271-273.
    """
    
    def __new__(cls, *args, **kwargs):
        if '_inst' not in vars(cls):
            cls._inst = super(Singleton, cls).__new__(cls, *args, **kwargs)
        return cls._inst
