from LigandAtom import LigandAtom

class Ligand(list):
    """Class Ligand

    The Ligand class is a container for instnces of the LigandAtom class.

    Examples:
    >>> from Ligand import Ligand
    >>> L = Ligand()
    >>> L.atom_input(1, 'O', 'O', 0.0, 0.0, 0.0, 2, 0)
    >>> L.atom_input(2, 'O', 'O', 0.0, 0.0, 0.0, 2, 0)
    >>> L.atom_input(3, 'C', 'C', 0.0, 0.0, 0.0, 2, 0)
    >>> len(L)
    3
    >>> len(L.polar_atoms)
    2
    >>> len(L.apolar_atoms)
    1

    """

    def atom_input(self, atomOriginalId, atomOriginalName, atomType, x, y, z,
        subAtomType, moleculeInstance):
        """function atomInput
        
        atomOriginalId: int
        atomOriginalName: string
        atomType: string
        x: float
        y: float
        z: float
        subAtomType: int
        moleculeInstance: int

        This method is used to input a new LigandAtom into the list.

        See the Atom class for explanations of the arguments passed into
        this method.
        
        """
        self.append(LigandAtom(atomOriginalId,
                               atomOriginalName,
                               atomType,
                               x, y, z,
                               subAtomType,
                               moleculeInstance))
        self[-1].include = 1

    @property
    def polar_atoms(self):
        """
        Return list of polar atoms.
        """
        polarList = []
        for atom in self:
            if atom.atom_polarity == 0:
                polarList.append(atom)
        return polarList
        
    
    @property
    def apolar_atoms(self):
        """
        Return list of apolar atoms
        """
        apolarList = []
        for atom in self:
            if atom.atom_polarity == 2:
                apolarList.append(atom)
        return apolarList
    
    def clear(self):
        """
        Clear list.

        Including neighbor lists and surface points.

        """
        for atom in self:
            atom.clear_neighbors()
            atom.clear_surface()
        del self[:]
        
# Test Ligand class by 'python Ligand.py'
if __name__ == "__main__":
    import doctest
    doctest.testmod()
